@@ -1,5 +1,5 @@
 #!/bin/bash
-#  Copyright (C) 2000-2006 SWsoft. All rights reserved.
+#  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -16,32 +16,7 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-# This script sets up hostname inside VE for RedHat like system
-# For usage info see vz-veconfig(5) man page.
-#
-# Some parameters are passed in environment variables.
-# Required parameters:
-# Optional parameters:
-#   HOSTNM
-#       Sets host name for this VE. Modifies /etc/hosts and
-#       /etc/sysconfig/network (in RedHat) or /etc/rc.config (in SuSE)
-function set_host()
-{
-	local cfgfile="$1"
-	local var=$2
-	local val=$3
-	local host=
-
-	[ -z "${val}" ] && return 0
-        if grep -q -E "[[:space:]]${val}" ${cfgfile} 2>/dev/null; then
-                return;
-        fi
-	if echo "${val}" | grep "\." >/dev/null 2>&1; then
-		host=${val%%.*}
-	fi
-	host=" ${val} ${host}"
-	put_param2 "${cfgfile}" "${var}" "${host} localhost localhost.localdomain"
-}
+# Sets up hostname in a container running Red Hat-like distro.
 
 function set_hostname()
 {
@@ -50,12 +25,13 @@ function set_hostname()
 	local val=$3
 
 	[ -z "${val}" ] && return 0
+
 	put_param "${cfgfile}" "${var}" "${val}"
 
 	hostname "${val}"
 }
 
-set_host /etc/hosts "127.0.0.1" "${HOSTNM}"
+change_hostname /etc/hosts "${HOSTNM}" "${IP_ADDR}"
 set_hostname /etc/sysconfig/network HOSTNAME "${HOSTNM}"
 
 exit 0
